@@ -1,9 +1,11 @@
 import logging
 from pathlib import Path
-from typing import Any, Dict, List
+from typing import List
 
 from jinja2 import StrictUndefined, Template
 
+from templateco.typing import Answers
+
 logger = logging.getLogger(__name__)
 
 
@@ -11,16 +13,10 @@ def _template_file(
     input_file: Path,
     template_directory: Path,
     output_directory: Path,
-    data: Dict[str, Any],
+    answers: Answers,
 ) -> None:
     """
     Take an input file, and generate a fully templated output file to the filesystem.
-
-    :param input_file: File within the plugin.
-    :param output_directory: Directory to output to.
-    :param template_directory: Path to the directory to template.
-    :param data: Data to template with.
-    :return: None.
     """
     relative_path = input_file.relative_to(template_directory)
 
@@ -28,7 +24,7 @@ def _template_file(
     stripped_path = str(relative_path).rstrip(".jinja2")
 
     rendered_path = (
-        Template(stripped_path, undefined=StrictUndefined).render(**data).split(";")
+        Template(stripped_path, undefined=StrictUndefined).render(**answers).split(";")
     )
     logger.debug(f"[{relative_path}] Rendered path: {rendered_path}")
 
@@ -40,18 +36,21 @@ def _template_file(
             # Make the parent directory if it doesn't exist.
             Path(output_path).parent.mkdir(parents=True, exist_ok=True)
 
+            # Additional metadata to add as _metadata.
+            metadata = {"_file_name": templated_path.lstrip("/")}
+
             with open(input_file.absolute(), "r") as file:
                 logger.debug(f"[{relative_path}] Outputting templated file.")
-                Template(file.read(), undefined=StrictUndefined).stream(**data).dump(
-                    str(output_path)
-                )
+                Template(file.read(), undefined=StrictUndefined).stream(
+                    {**answers, "_metadata": metadata}
+                ).dump(str(output_path))
 
 
 def generate_output(
     input_directory: Path,
     output_directory: Path,
     folders_to_template: List[str],
-    data: Dict[str, Any],
+    answers: Answers,
 ) -> None:
     """
     Output a templated folder structure.
@@ -59,8 +58,8 @@ def generate_output(
     :param input_directory: Path to input folder structure.
     :param output_directory: Path to output templated files to.
     :param folders_to_template: List of template folders.
-    :param data: Dictionary of data.
-    :return: None.
+    :param answers: Dictionary of data.
+    :return None.
     """
     files_to_template = (
         (input_file, input_directory / folder)
@@ -70,4 +69,4 @@ def generate_output(
 
     # Iterate over the files to template, and generate them.
     for (input_file, template_directory) in files_to_template:
-        _template_file(input_file, template_directory, output_directory, data)
+        _template_file(input_file, template_directory, output_directory, answers)
