@@ -1,11 +1,12 @@
 import logging
-from dataclasses import dataclass
+from dataclasses import MISSING, dataclass, fields
 from functools import lru_cache
 from importlib import import_module
 from pathlib import Path
-from typing import Generator, Iterable, List, Optional
+from typing import Any, Generator, Iterable, List, Optional
 
 from importlib_metadata import Distribution, distributions
+from typeguard import check_type
 
 from templateco.exceptions import IncompatiblePluginException
 from templateco.typing import (
@@ -18,44 +19,54 @@ from templateco.typing import (
 logger = logging.getLogger(__name__)
 
 
-@dataclass
+@dataclass(init=False)
 class TemplatecoPlugin:
     """
     Templateco Plugin.
     """
 
+    package_name: str
     friendly_name: str
     path_to_module: Path
     compatible_languages: List[str]
-    selected_by_default: bool
     get_questions: GetQuestions
     folders_to_template: FoldersToTemplate
-    pre_template_hook: Optional[PreTemplateHook]
-    post_template_hook: Optional[PostTemplateHook]
+    selected_by_default: bool = False
+    pre_template_hook: Optional[PreTemplateHook] = None
+    post_template_hook: Optional[PostTemplateHook] = None
+
+    def __init__(self, **kwargs: Any) -> None:
+        """
+        Initialise the plugin by discarding all kwargs that aren't specified as args.
+        """
+        for field in fields(self):
+            value = kwargs.get(field.name, MISSING)
+
+            if value is MISSING and field.default is not MISSING:
+                value = field.default
+
+            check_type(field.name, value, field.type)
+            setattr(self, field.name, value)
 
 
 @lru_cache(maxsize=None)
-def import_templateco_plugin(name: str) -> TemplatecoPlugin:
+def _import_templateco_plugin(name: str) -> TemplatecoPlugin:
     """
     Import a compatible Templateco package, and return a TemplatecoPlugin.
 
     :param name: Name of Python package.
-    :return: Templateco Plugin.
+    :raises IncompatiblePluginException
+    :return Templateco Plugin.
     """
     module = import_module(name.replace("-", "_"))
 
     try:
         return TemplatecoPlugin(
-            friendly_name=module.__dict__["friendly_name"],
+            **module.__dict__,
+            package_name=name,
             path_to_module=Path(str(module.__file__)).parent,
-            compatible_languages=module.__dict__["compatible_languages"],
-            selected_by_default=module.__dict__.get("selected_by_default", False),
-            get_questions=module.__dict__["get_questions"],
-            folders_to_template=module.__dict__["folders_to_template"],
-            pre_template_hook=module.__dict__.get("pre_template_hook", None),
-            post_template_hook=module.__dict__.get("post_template_hook", None),
         )
-    except KeyError as err:
+    except (KeyError, TypeError) as err:
         logger.debug(f"[{name}] Failed to parse plugin information.")
         logger.debug(err)
         raise IncompatiblePluginException(err)
@@ -68,7 +79,7 @@ def list_compatible_plugins(
     Return a list of compatible Templateco plugins.
 
     :param namespaces: List of Templateco plugin namespaces to accept.
-    :return: List of Templateco plugins.
+    :return Iterable containing Templateco plugins.
     """
     logger.debug("Getting list of Python distributions.")
 
@@ -80,7 +91,7 @@ def list_compatible_plugins(
             if split_package[0] in namespaces and distribution.name[-6:] == "plugin":
                 logger.debug(f"[{distribution.name}] Found potential plugin.")
                 try:
-                    yield import_templateco_plugin(distribution.name)
+                    yield _import_templateco_plugin(distribution.name)
                     logger.debug(f"[{distribution.name}] Successfully loaded plugin.")
                 except IncompatiblePluginException:
                     logger.debug(f"[{distribution.name}] Plugin incompatible.")
