@@ -1,6 +1,6 @@
 import logging
 from pathlib import Path
-from typing import Any, Dict, List
+from typing import List, Tuple
 
 from colorama import Fore, Style, init
 from questionary import Choice, checkbox, unsafe_prompt
@@ -8,12 +8,17 @@ from questionary import Choice, checkbox, unsafe_prompt
 from templateco.exceptions import NoPluginsFoundException, PluginOperationException
 from templateco.output import generate_output
 from templateco.plugin import TemplatecoPlugin, list_compatible_plugins
+from templateco.typing import Config
 
 logger = logging.getLogger(__name__)
 
 
 def _execute_plugin(
-    language: str, folder: Path, plugin: TemplatecoPlugin, config: Dict[str, Any]
+    language: str,
+    folder: Path,
+    plugin: TemplatecoPlugin,
+    config: Config,
+    plugins: Tuple[str, ...],
 ) -> None:
     """
     Execute a single Templateco plugin.
@@ -25,16 +30,19 @@ def _execute_plugin(
     :param folder: Folder to output to.
     :param plugin: Plugin to execute.
     :param config: Extra configuration passed to Templateco.
-    :return: None.
+    :return None.
     """
     logger.debug(f"[{plugin.friendly_name}] Running plugin.")
     try:
         top_level_folder_name = folder.name
         logger.debug(f"[{plugin.friendly_name}] Prompting for interaction.")
 
-        data = unsafe_prompt(
+        answers = unsafe_prompt(
             plugin.get_questions(
-                language=language, folder=top_level_folder_name, config=config
+                language=language,
+                folder=top_level_folder_name,
+                config=config,
+                plugins=plugins,
             )
         )
 
@@ -44,16 +52,21 @@ def _execute_plugin(
                 language=language,
                 folder=top_level_folder_name,
                 config=config,
-                data=data,
+                answers=answers,
+                plugins=plugins,
             )
 
         logger.debug(f"[{plugin.friendly_name}] Determining template from answers.")
         folders = plugin.folders_to_template(
-            language=language, folder=top_level_folder_name, config=config, data=data
+            language=language,
+            folder=top_level_folder_name,
+            config=config,
+            answers=answers,
+            plugins=plugins,
         )
 
         logger.debug(f"[{plugin.friendly_name}] Templating folder structure.")
-        generate_output(plugin.path_to_module, folder, folders, data)
+        generate_output(plugin.path_to_module, folder, folders, answers)
         logger.debug(f"[{plugin.friendly_name}] Successfully templated.")
 
         if plugin.post_template_hook:
@@ -63,7 +76,8 @@ def _execute_plugin(
                 folder=top_level_folder_name,
                 output_folder=folder,
                 config=config,
-                data=data,
+                answers=answers,
+                plugins=plugins,
             )
     except PluginOperationException:
         logger.error(f"[{plugin.friendly_name}] Plugin raised an operation exception:")
@@ -80,7 +94,7 @@ def templateco(
     *,
     language: str,
     folder: Path,
-    config: Dict[str, Any] = {},
+    config: Config = {},
     namespaces: List[str] = ["templateco"],
 ) -> None:
     """
@@ -93,7 +107,7 @@ def templateco(
     :param folder: Folder to generate e.g. $(PWD)/output_folder.
     :param config: Extra configuration passed to Templateco.
     :param namespaces: List of Templateco plugin namespaces to accept.
-    :return: None.
+    :return None.
     """
     # Initialise Colorama for terminal output.
     init(autoreset=True)
@@ -134,8 +148,10 @@ def templateco(
             ],
         ).unsafe_ask()
 
+    name_of_plugins = tuple(plugin.package_name for plugin in plugins)
+
     for plugin in plugins:
         print("\nConfiguring " + Fore.GREEN + Style.BRIGHT + f"{plugin.friendly_name}")
-        _execute_plugin(language, folder, plugin, config)
+        _execute_plugin(language, folder, plugin, config, name_of_plugins)
 
     print("\nSuccessfully templated " + Style.BRIGHT + Fore.GREEN + str(folder))
