@@ -1,8 +1,14 @@
 from pathlib import Path
-from typing import Any, Dict, Iterable, List, Mapping
+from typing import Any, Dict, Iterable, List, Mapping, Tuple
 
 from typing_extensions import Protocol, runtime_checkable
 
+# Type Aliases.
+Config = Dict[str, Any]
+Answers = Dict[str, Any]
+Questions = Iterable[Mapping[str, Any]]
+Plugins = Tuple[str, ...]
+
 
 @runtime_checkable
 class GetQuestions(Protocol):
@@ -11,15 +17,21 @@ class GetQuestions(Protocol):
     """
 
     def __call__(
-        self, *, language: str, folder: str, config: Dict[str, Any]
-    ) -> Iterable[Mapping[str, Any]]:
+        self,
+        *,
+        language: str,
+        folder: str,
+        config: Config,
+        plugins: Plugins,
+    ) -> Questions:
         """
         Return a Questionary dictionary-type iterable.
 
-        :param language: Name of the requested template.
+        :param language: Name of the requested language.
         :param folder: Name of the top-level folder.
         :param config: Extra configuration passed to Templateco.
-        :return: Dictionary of data passed to the template.
+        :param plugins: Tuple containing all of the plugins selected.
+        :return Dictionary of answers from the questionnaire.
         """
         pass
 
@@ -35,8 +47,9 @@ class FoldersToTemplate(Protocol):
         *,
         language: str,
         folder: str,
-        config: Dict[str, Any],
-        data: Dict[str, Any]
+        config: Config,
+        answers: Answers,
+        plugins: Plugins,
     ) -> List[str]:
         """
         Take all input and returns a list of folders within the plugin.
@@ -44,11 +57,12 @@ class FoldersToTemplate(Protocol):
         These folders are used to specify which should be templated, and intended to
         support optional configuration.
 
-        :param language: Name of the requested template.
+        :param language: Name of the requested language.
         :param folder: Name of the top-level folder.
         :param config: Extra configuration passed to Templateco.
-        :param data: Dictionary of data passed to the template.
-        :return: List of folders to template.
+        :param answers: Dictionary of answers from the questionnaire.
+        :param plugins: Tuple containing all of the plugins selected.
+        :return List of folders to template.
         """
         pass
 
@@ -64,11 +78,12 @@ class PreTemplateHook(Protocol):
         *,
         language: str,
         folder: str,
-        config: Dict[str, Any],
-        data: Dict[str, Any]
+        config: Config,
+        answers: Answers,
+        plugins: Plugins,
     ) -> None:
         """
-        Run before a plugin creates a template.
+        Run before a plugin creates a language.
 
         This optional function is intended to be used to modify the data dictionary
         that's passed to Jinja2 for the templating.
@@ -76,8 +91,9 @@ class PreTemplateHook(Protocol):
         :param language: Name of the requested template.
         :param folder: Name of the top-level folder.
         :param config: Extra configuration passed to Templateco.
-        :param data: Dictionary of data passed to the template.
-        :return: Nothing.
+        :param answers: Dictionary of answers from the questionnaire.
+        :param plugins: Tuple containing all of the plugins selected.
+        :return Nothing.
         """
         pass
 
@@ -94,8 +110,9 @@ class PostTemplateHook(Protocol):
         language: str,
         folder: str,
         output_folder: Path,
-        config: Dict[str, Any],
-        data: Dict[str, Any]
+        config: Config,
+        answers: Answers,
+        plugins: Plugins,
     ) -> None:
         """
         Run after a plugin has successfully templated.
@@ -104,12 +121,13 @@ class PostTemplateHook(Protocol):
         has been run, and passes in the path to the final directory. This can be used
         to run CLI commands, or alter the folder data if wished.
 
-        :param language: Name of the requested template.
+        :param language: Name of the requested language.
         :param folder: Name of the top-level folder.
         :param output_folder: Path to the generated folder.
         :param config: Extra configuration passed to Templateco.
-        :param data: Dictionary of data passed to the template.
-        :return: Nothing.
+        :param answers: Dictionary of answers from the questionnaire.
+        :param plugins: Tuple containing all of the plugins selected.
+        :return Nothing.
         """
         pass
 
